<?php

declare(strict_types=1);
namespace Drupal\confirmation_example\Entity;

use Drupal\bca\Attribute\Bundle;
use Drupal\confirmation\Entity\Confirmation;
use Drupal\confirmation\Entity\ConfirmationWithEmailInterface;
use Drupal\confirmation\Entity\RequiredEmailFieldTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\node\NodeInterface;

#[Bundle(
  entityType: 'confirmation',
  bundle: 'confirmation_example',
  label: new TranslatableMarkup('Confirmation example'),
  define: true,
)]
class ExampleConfirmationBundle extends Confirmation implements ConfirmationWithEmailInterface {

  use StringTranslationTrait;
  use RequiredEmailFieldTrait;

  public static function bundleFieldDefinitions(EntityTypeInterface $entity_type, $bundle, array $base_field_definitions) {
    $fields['confirmation_example__node'] = BaseFieldDefinition::create('entity_reference')
      ->setRequired(TRUE)
      ->setSetting('target_type', 'node')
      ->setLabel(t('Referenced Node'))
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    self::makeEmailFieldRequired($fields, $base_field_definitions);

    return $fields;
  }

  public function getNode(): NodeInterface {
    return $this->get('confirmation_example__node')->first()->get('entity')->getValue();
  }

  /**
   * @return $this
   */
  public function setNode(NodeInterface $node) {
    $this->set('confirmation_example__node', $node);
    return $this;
  }

  public function getConfirmationQuestion() {
    return $this->t('Confirm publishing of node: %label', ['%label' => $this->getNode()->label()]);
  }

}
